@@ -1,3 +1,4 @@
+import inspect
 import itertools
 from typing import List, Tuple, Union, Callable
 from .message import Message, PrivateMessage
@@ -7,13 +8,22 @@ from .chat import DGGChat
 class DGGBot(DGGChat):
     def __init__(
         self,
-        auth_token: str,
+        auth_token: str = None,
         username: str = None,
         owner: str = None,
         prefix="!",
         wss: str = None,
+        *,
+        sid: str = None,
+        rememberme: str = None,
     ):
-        super().__init__(auth_token=auth_token, username=username, wss=wss)
+        super().__init__(
+            auth_token=auth_token,
+            username=username,
+            wss=wss,
+            sid=sid,
+            rememberme=rememberme,
+        )
         self._owner = owner.lower() if owner else None
         self.prefix = prefix
         self._commands = {}
@@ -33,6 +43,7 @@ class DGGBot(DGGChat):
         """
 
         def decorator(func: Callable):
+            func._args = inspect.getfullargspec(func)
             if whisper_only:
                 func = self.check(lambda msg: isinstance(msg, PrivateMessage))(func)
             for cmd_name in itertools.chain((func.__name__,), aliases):
@@ -50,11 +61,15 @@ class DGGBot(DGGChat):
     def on_command(self, msg: Message):
         cmd = msg.data.split(" ")[0][1:]
         if cmd in self._commands:
-            if hasattr(self._commands[cmd], "_perms"):
-                perms = self._commands[cmd]._perms
+            func: callable = self._commands[cmd]
+            if hasattr(func, "_perms"):
+                perms = func._perms
                 if any(not perm(msg) for perm in perms):
                     return
-            self._commands[cmd](msg)
+            args = msg.data.split(" ", len(func._args.args) - (not func._args.varargs))[
+                1:
+            ]
+            func(msg, *args)
 
     def check(self, *check_funcs: Callable):
         """
