@@ -1,12 +1,13 @@
 from datetime import datetime, timezone
 import json
+import time
 from typing import Callable, Union
 import websocket
 
 from .event import EventType
 from ._logging import _logger
 from .funcs import threaded
-from .message import Message, PrivateMessage, MuteMessage
+from .message import Message, MuteMessage, PinnedMessage, PrivateMessage
 from .user import User
 from .errors import (
     AccountTooYoung,
@@ -136,6 +137,17 @@ class DGGChat:
             _logger.debug(f"{event_type} {data}")
             self.on_names(data["connectioncount"], data["users"])
             return
+        elif event_type == EventType.PIN:
+            msg = PinnedMessage(
+                self,
+                event_type,
+                data["nick"],
+                self._dggtime_to_dt(data["createdDate"]),
+                data["features"],
+                self._dggepoch_to_dt(data["timestamp"]),
+                data.get("data"),
+                data["uuid"],
+            )
         elif event_type in (
             EventType.MESSAGE,
             EventType.UNMUTE,
@@ -230,6 +242,12 @@ class DGGChat:
         for func in self._events.get("on_names", tuple()):
             func(connection_count, users)
 
+    @threaded
+    def on_pin(self, msg: PinnedMessage):
+        """Do stuff when a PIN is received."""
+        for func in self._events.get("on_pin", tuple()):
+            func(msg)
+
     @threaded
     def on_privmsg(self, msg: PrivateMessage):
         """Do stuff when a PRIVMSG is received."""
@@ -239,6 +257,12 @@ class DGGChat:
     def run(self, origin: str = None):
         self.ws.run_forever(origin=origin or self.URL)
 
+    def run_forever(self, origin: str = None, sleep: int = 2):
+        """Runs the client forever by automatically reconnecting the websocket."""
+        while True:
+            self.run(origin=origin or self.URL)
+            time.sleep(sleep)
+
     @threaded
     def send(self, msg: str):
         """Send a message to chat."""
